summaryrefslogtreecommitdiffstats
path: root/src/include/console.h
diff options
context:
space:
mode:
authorAnselm Martin Hoffmeister2007-04-09 20:01:43 +0200
committerAnselm Martin Hoffmeister2007-04-09 20:01:43 +0200
commited7dc02a95026f85cdd4c2c350a034458343d340 (patch)
tree885147a1e94a401fe5716514f2d8a15fbaf6c980 /src/include/console.h
parenthoffmeis: Fixing situation where absence of a newdata() handler for UDP (diff)
downloadipxe-ed7dc02a95026f85cdd4c2c350a034458343d340.tar.gz
ipxe-ed7dc02a95026f85cdd4c2c350a034458343d340.tar.xz
ipxe-ed7dc02a95026f85cdd4c2c350a034458343d340.zip
hoffmeis: Preparations for syslog support (LOGSERVER in DHCP, linewise
output buffering defintions and the like)
Diffstat (limited to 'src/include/console.h')
-rw-r--r--src/include/console.h15
1 files changed, 13 insertions, 2 deletions
diff --git a/src/include/console.h b/src/include/console.h
index b1fe955b..fd1382b4 100644
--- a/src/include/console.h
+++ b/src/include/console.h
@@ -30,8 +30,8 @@
struct console_driver {
/** Console is disabled.
*
* The console's putchar(), getchar() and iskey() methods will
* not be called while #disabled==1. Typically the
* console's initialisation functions (called via INIT_FN())
* will set #disabled=0 upon completion.
*
@@ -47,6 +47,17 @@ struct console_driver {
*/
void ( *putchar ) ( int character );
+ /** Write an entire line to the console.
+ * This is intended to be used by line-oriented output media,
+ * like system logging facilities or line printers.
+ * Line output will not contain non-printable characters.
+ *
+ * @v linebuffer Pointer to the \0-terminated line
+ * @ret None -
+ * @err None -
+ */
+ void ( * putline ) ( unsigned char * linebuffer );
+
/** Read a character from the console.
*
* @v None -
@@ -30,8 +30,8 @@
/** Console is disabled.
*
- * The console's putchar(), getchar() and iskey() methods will
- * not be called while #disabled==1. Typically the
+ * The console's putchar(), putline(), getchar() and iskey()
+ * methods will not be called while #disabled==1. Typically the
* console's initialisation functions (called via INIT_FN())
* will set #disabled=0 upon completion.